#
# spec file for package ulogd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ulogd
Version:        2.0.5
Release:        lp151.2.3
Summary:        Userspace logging for Netfilter
License:        GPL-2.0
Group:          Productivity/Networking/Security
Url:            http://netfilter.org/projects/ulogd/

#Git-Clone:	git://git.netfilter.org/ulogd2
#DL-URL:	http://netfilter.org/projects/ulogd/files/
Source:         http://netfilter.org/projects/ulogd/files/%name-%version.tar.bz2
Source2:        http://netfilter.org/projects/ulogd/files/%name-%version.tar.bz2.sig
Source4:        ulogd.service
Patch4:         ulogd-conf.diff

BuildRequires:  autoconf >= 2.50
BuildRequires:  automake >= 1.11
BuildRequires:  libmysqlclient-devel
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
BuildRequires:  pkgconfig(libmnl) >= 1.0.3
BuildRequires:  pkgconfig(libnetfilter_acct) >= 1.0.1
BuildRequires:  pkgconfig(libnetfilter_conntrack) >= 1.0.2
BuildRequires:  pkgconfig(libnetfilter_log) >= 1.0.0
BuildRequires:  pkgconfig(libnfnetlink) >= 1.0.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  systemd-rpm-macros
Requires(pre):	/usr/sbin/useradd

%description
ulogd is a userspace logging daemon for netfilter/iptables related
logging. This includes per-packet logging of security violations,
per-packet logging for accounting purpose as well as per-flow
logging.

%package mysql
Summary:        MySQL output target for ulogd
Group:          Productivity/Networking/Security
Requires:       %name = %version-%release

%description mysql
MySQL output target for ulogd.

%package pcap
Summary:        pcap output target for ulogd
Group:          Productivity/Networking/Security
Requires:       %name = %version-%release

%description pcap
pcap output target for ulogd.

%package pgsql
Summary:        PostgreSQL output target for ulogd
Group:          Productivity/Networking/Security
Requires:       %name = %version-%release

%description pgsql
PostgreSQL output target for ulogd.

%package sqlite3
Summary:        SQLite3 output target for ulogd
Group:          Productivity/Networking/Security
Requires:       %name = %version-%release

%description sqlite3
SQLite3 output target for ulogd.

%prep
%setup -q
%patch -P 4 -p1

%build
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

%install
b="%buildroot"
make install DESTDIR="$b"
find "$b" -type f -iname "*.la" -delete
mkdir -p "$b/var/log/ulogd"
mkdir -p "$b/%_sysconfdir"
install -pm0644 ulogd.conf "$b/%_sysconfdir/"
mkdir -p "$b/%_unitdir"
install -pm0644 "%{S:4}" "$b/%_unitdir"
ln -s /sbin/service "$b/%_sbindir/rc%name"

%pre
/usr/bin/getent passwd ulogd >/dev/null || \
/usr/sbin/useradd -c "Userspace logging daemon for Netfilter" -r ulogd
%service_add_pre ulogd.service

%post
%service_add_post ulogd.service

%preun
%service_del_preun ulogd.service

%postun
%service_del_postun ulogd.service

%files
%defattr(-,root,root)
%config(noreplace) %_sysconfdir/ulogd.conf
%_sbindir/ulogd
%dir %_libdir/%name
%_libdir/%name/ulogd_[fir]*.so*
%_libdir/%name/ulogd_output_GRAPHITE.so*
%_libdir/%name/ulogd_output_GPRINT.so*
%_libdir/%name/ulogd_output_LOGEMU.so*
%_libdir/%name/ulogd_output_NACCT.so*
%_libdir/%name/ulogd_output_OPRINT.so*
%_libdir/%name/ulogd_output_SYSLOG.so*
%_libdir/%name/ulogd_output_XML.so*
%_mandir/*/*
%attr(0750,ulogd,root) /var/log/ulogd
%_unitdir/ulogd.service
%_sbindir/rc%name

# These are the dependency-heavy things:

%files mysql
%defattr(-,root,root)
%_libdir/%name/ulogd_output_MYSQL.so*

%files pcap
%defattr(-,root,root)
%_libdir/%name/ulogd_output_PCAP.so*

%files pgsql
%defattr(-,root,root)
%_libdir/%name/ulogd_output_PGSQL.so*

%files sqlite3
%defattr(-,root,root)
%_libdir/%name/ulogd_output_SQLITE3.so*

%changelog
* Sat Mar 11 2017 jengelh@inai.de
- Drop init.d script and insserv use.
- Propagate useradd failure and abort install if necessary.
* Sun May 10 2015 jengelh@inai.de
- Update to new upstream release 2.0.5
  * JSON output on bigendian arches was fixed
  * Support absence of ipt_ULOG.h
- Remove 0001-include-keep-a-copy-of-linux-netfilter_ipv4-ipt_ULOG.patch
* Thu Nov 27 2014 jengelh@inai.de
- Add 0001-include-keep-a-copy-of-linux-netfilter_ipv4-ipt_ULOG.patch
  to cope with new linux-glibc-devel which lacks ipt_ULOG.h needed
  for compilation.
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 2.0.4
  * ulogd 2.0.4 features a new JSON output plugin allowing easy
  integration with log management systems.
* Sat Nov 23 2013 jengelh@inai.de
- Update to new upstream release 2.0.3
  * Optional backlog system to avoid event loss in case of database
  downtime
  * Optional running mode where acquisition is made in one thread
  and queries to databases are made in separate threads
* Mon Mar  4 2013 jengelh@inai.de
- Update to new upstream release 2.0.2
  * Add GRAPHITE output module
  * Add src, dst and protocol filters to nfct plugin
  * Fix parsing of ipv6 flowlabel and tc fields
  * Add additional ip6 header fields to database scripts
* Mon Oct  8 2012 jengelh@inai.de
- Update to new upstream release 2.0.1
  * This releases includes support for the nfacct extended iptables
  accounting infrastructure.
- Snapshot 2.0.1+git11
  * Build fixes for 2.0.1
* Tue Jun 26 2012 jengelh@inai.de
- Update to 2.0.0 final release
  * add documentation about SIGUSR2 handling
  * (compile fail-fixing patches were merged, no functional changes)
* Wed Jan  4 2012 jengelh@medozas.de
- build description update
- git snapshot 2.0.0~beta4+git51
  * pcap: add file option to configuration file
  * ulogd: fix segfault if syslog and SIGTERM is received
  * sqlite3 backend: remove automatic creation of table "daily"
  * add nfacct and GPRINT plugins
- add systemd service file
* Thu Dec  1 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Feb  1 2011 jengelh@medozas.de
- Add init script
- Install config file
* Wed Sep 15 2010 jengelh@medozas.de
- Added /var/log/ulogd, and gave it to the newly-created user
  "ulogd". (http://bugzilla.netfilter.org/show_bug.cgi?id=665)
* Fri Jul 16 2010 jengelh@medozas.de
- New upstream release 2.0.0~beta4
  * new XML output plugin for packet and log-based logging
  * several fixes, improvements
* Tue Feb 23 2010 jengelh@medozas.de
- Initial upload, version 2.0.0~beta3
